==> foundation-ui-components-1.26.1.tgz: package/src/common/checkbox/NsCheckbox.tsx <==
/**
 * @author [Vijayaprathap Kumar] (vpkumar@nuskin.com)
 * checkbox.tsx
 * @description
 */

import React, { PropsWithChildren, useCallback } from 'react';
import FormControlLabel from '@mui/material/FormControlLabel';
import { default as MUICheckbox } from '@mui/material/Checkbox';

import { BpCheckedIcon, BpIcon, StyledLabel, StyledFlagLabel } from './NsCheckbox.styled';
import { NsCheckboxProps } from './types.d';

import { NsTypography } from '../';

const NsCheckbox = (props: PropsWithChildren<NsCheckboxProps>) => {
    const {
        name,
        label,
        onChange,
        checked,
        ariaLabel = 'nuskin checkbox',
        flag,
        disabled = false,
        size = 'small',
        testid = 'nuskin-checkbox',
        className = '',
    } = props;

    const renderCheckbox = useCallback(
        () => (
            <MUICheckbox
                name={name}
                color="default"
                checked={checked}
                onChange={onChange}
                disabled={disabled}
                disableRipple
                checkedIcon={<BpCheckedIcon />}
                icon={<BpIcon />}
                inputProps={
                    {
                        'aria-label': ariaLabel,
                        'data-testid': testid,
                    } as React.InputHTMLAttributes<HTMLInputElement>
                }
                size={size}
            />
        ),
        [ariaLabel, checked, disabled, name, onChange, size, testid]
    );

    const renderCheckboxLabel = useCallback(
        () => (
            <NsTypography variant="body-l">
                <StyledFlagLabel {...flag} size={size} testId={`${name}-flag-label`} />
                <StyledLabel className="checkbox-label-text" isDisabled={disabled}>
                    {label}
                </StyledLabel>
            </NsTypography>
        ),
        [disabled, flag, label, name, size]
    );

    return <FormControlLabel className={className} control={renderCheckbox()} label={renderCheckboxLabel()} />;
};

export default NsCheckbox;

==> foundation-ui-components-1.30.1.tgz: package/src/common/checkbox/NsCheckbox.tsx <==
/**
 * @author [Vijayaprathap Kumar] (vpkumar@nuskin.com)
 * checkbox.tsx
 * @description
 */

import React, { PropsWithChildren, ReactElement, useCallback } from 'react';

import MUICheckbox from '@mui/material/Checkbox';
import FormControlLabel from '@mui/material/FormControlLabel';

import { NsTypography } from '../';
import { BpCheckedIcon, BpIcon, StyledFlagLabel, StyledLabel } from './NsCheckbox.styled';
import { NsCheckboxProps } from './types.d';

const NsCheckbox = (props: PropsWithChildren<NsCheckboxProps>): ReactElement => {
    const {
        name,
        label,
        onChange,
        checked,
        ariaLabel = 'nuskin checkbox',
        flag,
        disabled = false,
        size = 'small',
        testid = 'nuskin-checkbox',
        className = '',
    } = props;

    const renderCheckbox = useCallback(
        () => (
            <MUICheckbox
                name={name}
                color="default"
                checked={checked}
                onChange={onChange}
                disabled={disabled}
                disableRipple
                checkedIcon={<BpCheckedIcon />}
                icon={<BpIcon />}
                inputProps={
                    {
                        'aria-label': ariaLabel,
                        'data-testid': testid,
                    } as React.InputHTMLAttributes<HTMLInputElement>
                }
                size={size}
            />
        ),
        [ariaLabel, checked, disabled, name, onChange, size, testid]
    );

    const renderCheckboxLabel = useCallback(
        () => (
            <NsTypography variant="body-l">
                <StyledFlagLabel {...flag} size={size} testId={`${name}-flag-label`} />
                <StyledLabel className="checkbox-label-text" isDisabled={disabled}>
                    {label}
                </StyledLabel>
            </NsTypography>
        ),
        [disabled, flag, label, name, size]
    );

    return <FormControlLabel className={className} control={renderCheckbox()} label={renderCheckboxLabel()} />;
};

export default NsCheckbox;
